@@ -5,6 +5,8 @@ PREFIX="${PRINTNANNY_PREFIX:-.tmp/test}"
 CA_CERTS="$PREFIX/ca-certificates"
 KEYS="${PREFIX}/keys"
 DATA_DIR="${PREFIX}/data"
+VENV="${PREFIX}/venv"
+python3 -m venv "$VENV"
 mkdir -p "$KEYS"
 mkdir -p "$CA_CERTS"
 mkdir -p "$DATA_DIR"
